Returns a list of the diagnostics for each sampled variable. Each individual element of the list is a
data.frame containing at least the columns type, which is the type of diagnostic
(`Gelman-Rubin' or `Geweke'), stat, which is the value of the dignostic, and upper_ci which is
the upper confidence interval for the Gelman-Rubin diagnostic. For the Geweke diagnostic upper_ci
contains the value NA. Depending on the simulation performed the return from c212.convergence.diag will contain different
variables. The return for a simulation from c212.1a is as follows:
list(sim_type, gamma.conv.diag, theta.conv.diag, mu.gamma.conv.diag,
mu.theta.conv.diag, sigma2.gamma.conv.diag,
sigma2.theta.conv.diag, mu.gamma.0.conv.diag,
mu.theta.0.conv.diag, tau2.gamma.0.conv.diag,
tau2.theta.0.conv.diag)
Additional columns which may be used to identify the individual samples are B, the body-system, and
AE, the Adverse Event and interval.