Learn R Programming

c212 (version 0.98)

c212.print.convergence.summary: Print a Summary of the Convergence Diagnostics of the Simulation

Description

The function prints the maximum and minimum values of either Gelman-Rubin diagnostic or the Geweke diagnostic for each group of samples, e.g. theta, gamma, mu.gamma etc.

Usage

c212.print.convergence.summary(conv)

Arguments

conv

The output from a call to c212.convergence.diag.

Value

Nothing

Examples

Run this code
# NOT RUN {
data(c212.trial.data)
raw = c212.BB(c212.trial.data, burnin = 100, iter = 200)
conv = c212.convergence.diag(raw)
c212.print.convergence.summary(conv)
# }
# NOT RUN {
data(c212.trial.data)
raw = c212.BB(c212.trial.data)
conv = c212.convergence.diag(raw)
c212.print.convergence.summary(conv)
# }

Run the code above in your browser using DataLab